@@ -14,7 +14,7 @@ else:
     opt_import_error = None
 
 
-def _wrapper(stokes, spi, ref_freq, frequencies, base=None):
+def spectral_model_wrapper(stokes, spi, ref_freq, frequencies, base=None):
     return np_spectral_model(stokes, spi[0], ref_freq, frequencies, base=base)
 
 
@@ -25,7 +25,7 @@ def spectral_model(stokes, spi, ref_freq, frequencies, base=0):
 
     pol_dim = () if stokes.ndim == 1 else ("pol",)
 
-    return da.blockwise(_wrapper, ("source", "chan",) + pol_dim,
+    return da.blockwise(spectral_model_wrapper, ("source", "chan",) + pol_dim,
                         stokes, ("source",) + pol_dim,
                         spi, ("source", "spi") + pol_dim,
                         ref_freq, ("source",),
