@@ -13,7 +13,7 @@ else:
     opt_import_error = None
 
 
-def _wrapper(stokes, spi, log_si, ref_freq, frequency):
+def spectra_wrapper(stokes, spi, log_si, ref_freq, frequency):
     return np_spectra(stokes, spi[0], log_si, ref_freq, frequency)
 
 
@@ -22,7 +22,7 @@ def spectra(stokes, spi, log_si, ref_freq, frequency):
     corrs = tuple("corr-%d" % i for i in range(len(stokes.shape[1:])))
     log_si_schema = None if isinstance(log_si, bool) else ("source",)
 
-    return da.blockwise(_wrapper, ("source", "chan") + corrs,
+    return da.blockwise(spectra_wrapper, ("source", "chan") + corrs,
                         stokes, ("source",) + corrs,
                         spi, ("source", "spi") + corrs,
                         log_si, log_si_schema,
